#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-IH9fROZYC4lGWxxe2boKMv
key:                  sandi-0.5-IH9fROZYC4lGWxxe2boKMv
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  7f6a72b8fdd7033476189bc3649f56ee
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/sandi-0.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandi
hs-libraries:         HSsandi-0.5-IH9fROZYC4lGWxxe2boKMv
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-65VBuodW2FA1U1zRKEX2Oq exceptions-0.10.7

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

